@@ -73,7 +73,7 @@ Battery::Battery( TQString _udi ) {
 
 	udi = _udi;
 
-	connect(m_hwdevices, TQT_SIGNAL(hardwareUpdated(TDEGenericDevice*)), this, TQT_SLOT(updateProperty(TDEGenericDevice*)));
+	connect(m_hwdevices, TQ_SIGNAL(hardwareUpdated(TDEGenericDevice*)), this, TQ_SLOT(updateProperty(TDEGenericDevice*)));
 
 	initialized = false;
 
